@@ -1,4 +1,4 @@
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 from ._parser import parser
 from .rules import *
@@ -6,5 +6,4 @@ from .transformer import RuleTransformer
 
 
 def parse_rules(source: str) -> RulesList:
-    tree = parser.parse(source)
-    return RuleTransformer().transform(tree)
+    return parser.parse(source)
