@@ -3,12 +3,14 @@ from lark import Lark
 from .transformer import RuleTransformer
 
 grammar = r'''
-    %import common.ESCAPED_STRING   -> STRING
     %ignore " "
+    COMMENT: "#" /[^\r\n]/*
+    %ignore COMMENT
 
     _NEWLINE: /[\r\n]+/
     _ESCAPED_NEWLINE: /(\\(\r\n|\r|\n))+/
 
+    start: rules
     rules: (_NEWLINE* rule)* _NEWLINE*
 
     rule: action protocol target port direction target port "(" body ")"
@@ -18,28 +20,7 @@ grammar = r'''
            | "reject"
            | "alert"
 
-    !protocol: "ip"
-             | "tcp"
-             | "udp"
-             | "icmp"
-             | "http"
-             | "ftp"
-             | "tls"
-             | "smb"
-             | "dns"
-             | "dcerpc"
-             | "ssh"
-             | "smtp"
-             | "imap"
-             | "msn"
-             | "modbus"
-             | "dnp3"
-             | "enip"
-             | "nfs"
-             | "ikev2"
-             | "krb5"
-             | "ntp"
-             | "dhcp"
+    !protocol: /[^\s]+/
 
     ?target: any
            | target_spec
@@ -89,18 +70,24 @@ grammar = r'''
 
     body: _ESCAPED_NEWLINE* (option _ESCAPED_NEWLINE*)+
 
-    option: KEYWORD ";"
-          | KEYWORD ":" settings ";"
+    option: KEYWORD _SEMICOLON
+          | KEYWORD _COLON settings _SEMICOLON
 
-    KEYWORD: /[a-z_.]+/i
+    // Higher priorities, as these terminals are used to demarcate the option name
+    // and settings, in a context-free manner.
+    _COLON . 2: ":"
+    _SEMICOLON . 3: ";"
 
-    settings: string
-            | "!" string   -> negated_settings
-            | LITERAL
+    KEYWORD: /[a-z0-9_.\-]+/i
 
-    string: STRING
+    settings: "!" settings_expr   -> negated_settings
+            | settings_expr
 
-    LITERAL: /(?!\s+)([^;\\"]|(?!\\)\\[;\\"])+(?!\s+)/
+    ?settings_expr: STRING  -> string
+                  | LITERAL -> literal
+
+    STRING: /"[^\r\n]+?"(?=\s*[;])/
+    LITERAL: /(?!\s+)([^;\\"]|(?!\\)\\[;\\"])+(?=;)/
 '''
 
 parser = Lark(
